@@ -603,18 +603,18 @@ static struct testcase {
 	{ "/usr/local/", "/usr/\\*/", 1 },
 	{ "/usr/local/", "/usr/\\*\\*\\@\\*/", 1 },
 	{ "pipe:[12345]", "pipe:[\\$]", 1 },
-	{ "socket:[family=1:type=2:protocol=3]", "socket:[family=1:type=2:protocol=\\$]", 1 },
-	{ "http://tomoyo.osdn.jp/", "\\*/\\*/\\*/", 1 },
-	{ "http://tomoyo.osdn.jp/index.html", "\\*/\\*/\\*/\\*", 1 },
-	{ "http://tomoyo.osdn.jp/index.html", "\\*/\\*/\\*/\\*\\*\\@\\*\\@", 1 },
-	{ "http://tomoyo.osdn.jp/index.html", "\\*/\\@\\*/\\*\\@/\\*\\@\\*\\@\\*", 1 },
-	{ "http://tomoyo.osdn.jp/1.8/index.html", "http://\\{\\*\\}/\\@.html", 1 },
-	{ "http://tomoyo.osdn.jp/index.html", "\\*://\\@.osdn.jp/\\*", 1 },
-	{ "http://tomoyo.osdn.jp/index.html", "\\*://\\@.osdn.jp/\\*", 1 },
-	{ "http://osdn.jp/projects/tomoyo/svn/view/trunk/1.8.x/ccs-patch/security/ccsecurity/?root=tomoyo", "\\*://\\@osdn.jp/\\{\\*\\}/?root=tomoyo", 1 },
-	{ "http://osdn.jp/projects/tomoyo/svn/view/trunk/1.8.x/ccs-patch/security/?root=tomoyo", "\\*://\\@osdn.jp/\\{\\*\\}/?root=tomoyo", 1 },
-	{ "http://osdn.jp/projects/tomoyo/svn/view/trunk/1.8.x/ccs-patch/?root=tomoyo", "\\*://\\@osdn.jp/\\{\\*\\}/?root=tomoyo", 1 },
-	{ "http://osdn.jp/projects/tomoyo/svn/view/trunk/1.8.x//ccs-patch///security//ccsecurity///?root=tomoyo", "\\*://\\@osdn.jp/\\{\\*\\-.\\-..\\-\\*%\\*\\}/?root=tomoyo\\*\\*", 1 },
+	{ "socket:[12345]", "socket:[\\$]", 1 },
+	{ "https://tomoyo.osdn.jp/", "\\*/\\*/\\*/", 1 },
+	{ "https://tomoyo.osdn.jp/index.html", "\\*/\\*/\\*/\\*", 1 },
+	{ "https://tomoyo.osdn.jp/index.html", "\\*/\\*/\\*/\\*\\*\\@\\*\\@", 1 },
+	{ "https://tomoyo.osdn.jp/index.html", "\\*/\\@\\*/\\*\\@/\\*\\@\\*\\@\\*", 1 },
+	{ "https://tomoyo.osdn.jp/1.8/index.html", "https://\\{\\*\\}/\\@.html", 1 },
+	{ "https://tomoyo.osdn.jp/index.html", "\\*://\\@.osdn.jp/\\*", 1 },
+	{ "https://tomoyo.osdn.jp/index.html", "\\*://\\@.osdn.jp/\\*", 1 },
+	{ "https://osdn.jp/projects/tomoyo/svn/view/trunk/1.8.x/ccs-patch/security/ccsecurity/?root=tomoyo", "\\*://\\@osdn.jp/\\{\\*\\}/?root=tomoyo", 1 },
+	{ "https://osdn.jp/projects/tomoyo/svn/view/trunk/1.8.x/ccs-patch/security/?root=tomoyo", "\\*://\\@osdn.jp/\\{\\*\\}/?root=tomoyo", 1 },
+	{ "https://osdn.jp/projects/tomoyo/svn/view/trunk/1.8.x/ccs-patch/?root=tomoyo", "\\*://\\@osdn.jp/\\{\\*\\}/?root=tomoyo", 1 },
+	{ "https://osdn.jp/projects/tomoyo/svn/view/trunk/1.8.x//ccs-patch///security//ccsecurity///?root=tomoyo", "\\*://\\@osdn.jp/\\{\\*\\-.\\-..\\-\\*%\\*\\}/?root=tomoyo\\*\\*", 1 },
 	{ "/var/www/html/test/test/test/index.html", "/var/www/html/\\{test\\}/\\*.html", 1 },
 	{ "/etc/skel/", "/etc/\\{\\*\\}/\\*/", 0 },
 	{ "/etc/passwd", "/etc/\\{\\*\\}/\\*", 0 },
@@ -622,10 +622,10 @@ static struct testcase {
 	{ "/bin/", "/bin/\\*", 1 },
 	{ "/bin/", "/bin/\\@", 1 },
 	{ "/bin/", "/bin/\\@\\@", 1 },
-	{ "http://tomoyo.osdn.jp/", "\\*/\\*/\\*/\\?", 0 },
-	{ "http://tomoyo.osdn.jp/index.html", "\\*/\\*/\\*/\\@", 0 },
-	{ "http://tomoyo.osdn.jp/index.html", "http://\\*/\\@", 0 },
-	{ "socket:[family=1:type=2:protocol=3]", "/\\{\\*\\}/socket:[\\*]", 0 },
+	{ "https://tomoyo.osdn.jp/", "\\*/\\*/\\*/\\?", 0 },
+	{ "https://tomoyo.osdn.jp/index.html", "\\*/\\*/\\*/\\@", 0 },
+	{ "https://tomoyo.osdn.jp/index.html", "https://\\*/\\@", 0 },
+	{ "socket:[12345]", "/\\{\\*\\}/socket:[\\*]", 0 },
 	{ "/", "/\\(\\*\\)/\\*", 1 },
 	{ "/", "/\\{\\*\\}/\\*", 0 },
 	{ "/foo/", "/foo/\\(\\*\\)/\\(\\*\\)/\\(\\*\\)/\\(\\*\\)/\\(\\*\\)/\\*", 1 },
